##  Step 2. Monitor the Impact of Transformations
Using the Application Landscape Report and applying the Impact Type view, you can understand how the landscape has changed and been affected through the planned transformation.
![Application Landscape report showing the transformation impacts](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755bef67a441014b29f9e0ac79c8f15_LowRes.png)
Application Landscape report showing the transformation impacts
